@@ -1,6 +1,6 @@
 #[macro_use]
 mod error_handler;
 
-mod select_map;
+pub mod select_map;
 
 pub use select_map::{SelectMap, SelectMapExt};
